==> lms-1.1.5.tar.gz: lms/modules/userdel.php <==
<?php

/*
 * LMS version 1.1.5 Amaonet
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: userdel.php,v 1.21 2003/11/22 17:44:48 alec Exp $
 */

$layout[pagetitle]="Usunicie uytkownika ID: ".sprintf("%04d",$_GET[id]);
$SMARTY->assign("layout",$layout);
$SMARTY->assign("userid",$_GET[id]);

if (!$LMS->UserExists($_GET[id]))
{
	$body = "<H1>".$layout[pagetitle]."</H1><P>Podany przez Ciebie ID jest bdny bd nie istnieje w bazie danych.</P>";
}else{

	if($_GET[is_sure]!=1)
	{
		$body = "<H1>".$layout[pagetitle]."</H1>";
		$body .= "<P>Czy jeste pewien e chcesz usun uytkownika ".$LMS->GetUserName($_GET[id])."?</P>"; 
		$body .= "<P>Wszystkie dane uytkownika zostan utracone, a take wszystkie przypisane temu uytkownikowi komputery zostan usunite.</P>";
		$body .= "<P><A HREF=\"?m=userdel&id=".$_GET[id]."&is_sure=1\">Tak, jestem pewien.</A></P>";
	}else{
		header("Location: ?".$_SESSION[backto]);
		$body = "<H1>".$layout[pagetitle]."</H1>";
		$body .= "<P>Uytkownik ".$LMS->GetUserName($_GET[id])." zosta usunity.</P>";
		$LMS->DeleteUser($_GET[id]);
	}
		
}
$SMARTY->display("header.html");
$SMARTY->assign("body",$body);
$SMARTY->display("dialog.html");
$SMARTY->display("footer.html");

/*
 * $Log: userdel.php,v $
 * Revision 1.21  2003/11/22 17:44:48  alec
 * jeli usuwamy usera z listy to wracamy do listy, a nie do userinfo
 *
 * Revision 1.20  2003/08/27 20:32:54  lukasz
 * - changed another ENUM (users.deleted) to BOOL
 *
 * Revision 1.19  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.18  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>

==> lms-1.2.0rc1.tar.gz: lms/modules/userdel.php <==
<?php

/*
 * LMS version 1.2.0rc1 Janet
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: userdel.php,v 1.23.2.1 2004/02/18 12:47:20 lukasz Exp $
 */

$layout[pagetitle]="Usunicie uytkownika ID: ".sprintf("%04d",$_GET[id]);
$SMARTY->assign("layout",$layout);
$SMARTY->assign("userid",$_GET[id]);

if (!$LMS->UserExists($_GET[id]))
{
	$body = "<H1>".$layout[pagetitle]."</H1><P>Podany przez Ciebie ID jest bdny bd nie istnieje w bazie danych.</P>";
}else{

	if($_GET[is_sure]!=1)
	{
		$body = "<H1>".$layout[pagetitle]."</H1>";
		$body .= "<P>Czy jeste pewien e chcesz usun uytkownika ".$LMS->GetUserName($_GET[id])."?</P>"; 
		$body .= "<P>Wszystkie dane uytkownika zostan utracone, a take wszystkie przypisane temu uytkownikowi komputery zostan usunite.</P>";
		$body .= "<P><A HREF=\"?m=userdel&id=".$_GET[id]."&is_sure=1\">Tak, jestem pewien.</A></P>";
	}else{
		header("Location: ?".$_SESSION[backto]);
		$body = "<H1>".$layout[pagetitle]."</H1>";
		$body .= "<P>Uytkownik ".$LMS->GetUserName($_GET[id])." zosta usunity.</P>";
		$LMS->DeleteUser($_GET[id]);
	}
		
}

$SMARTY->display("header.html");
$SMARTY->assign("body",$body);
$SMARTY->display("dialog.html");
$SMARTY->display("footer.html");

?>
